@@ -108,7 +108,7 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, steps = NULL, hist = F
             xmax <- max(m@frame[var2], na.rm = T)
         
         if (is.null(steps)) {
-          steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$", 
+          steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", 
                                             var2, ")))")))
         }
         
@@ -308,7 +308,7 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, steps = NULL, hist =
             xmax <- max(m@frame[var2], na.rm = T)
         
         if (is.null(steps)) {
-          steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$", 
+          steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", 
                                             var2, ")))")))
         }
         
